==> nextcloud-12.0.3.tar.bz2: nextcloud/apps/dav/l10n/en_GB.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendar",
    "Todos" : "Todos",
    "{actor} created calendar {calendar}" : "{actor} created calendar {calendar}",
    "You created calendar {calendar}" : "You created calendar {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} deleted calendar {calendar}",
    "You deleted calendar {calendar}" : "You deleted calendar {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} updated calendar {calendar}",
    "You updated calendar {calendar}" : "You updated calendar {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} shared calendar {calendar} with you",
    "You shared calendar {calendar} with {user}" : "You shared calendar {calendar} with {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} shared calendar {calendar} with {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} unshared calendar {calendar} from you",
    "You unshared calendar {calendar} from {user}" : "You unshared calendar {calendar} from {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} unshared calendar {calendar} from {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} unshared calendar {calendar} from themselves",
    "You shared calendar {calendar} with group {group}" : "You shared calendar {calendar} with group {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} shared calendar {calendar} with group {group}",
    "You unshared calendar {calendar} from group {group}" : "You unshared calendar {calendar} from group {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} unshared calendar {calendar} from group {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} created event {event} in calendar {calendar}",
    "You created event {event} in calendar {calendar}" : "You created event {event} in calendar {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} deleted event {event} from calendar {calendar}",
    "You deleted event {event} from calendar {calendar}" : "You deleted event {event} from calendar {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} updated event {event} in calendar {calendar}",
    "You updated event {event} in calendar {calendar}" : "You updated event {event} in calendar {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} created todo {todo} in list {calendar}",
    "You created todo {todo} in list {calendar}" : "You created todo {todo} in list {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} deleted todo {todo} from list {calendar}",
    "You deleted todo {todo} from list {calendar}" : "You deleted todo {todo} from list {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} updated todo {todo} in list {calendar}",
    "You updated todo {todo} in list {calendar}" : "You updated todo {todo} in list {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} solved todo {todo} in list {calendar}",
    "You solved todo {todo} in list {calendar}" : "You solved todo {todo} in list {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reopened todo {todo} in list {calendar}",
    "You reopened todo {todo} in list {calendar}" : "You reopened todo {todo} in list {calendar}",
    "A <strong>calendar</strong> was modified" : "A <strong>calendar</strong> was modified",
    "A calendar <strong>event</strong> was modified" : "A calendar <strong>event</strong> was modified",
    "A calendar <strong>todo</strong> was modified" : "A calendar <strong>todo</strong> was modified",
    "Contact birthdays" : "Contact birthdays",
    "Personal" : "Personal",
    "Contacts" : "Contacts",
    "Technical details" : "Technical details",
    "Remote Address: %s" : "Remote Address: %s",
    "Request ID: %s" : "Request ID: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.11.tar.bz2: nextcloud/apps/dav/l10n/en_GB.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendar",
    "Todos" : "Todos",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} created calendar {calendar}",
    "You created calendar {calendar}" : "You created calendar {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} deleted calendar {calendar}",
    "You deleted calendar {calendar}" : "You deleted calendar {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} updated calendar {calendar}",
    "You updated calendar {calendar}" : "You updated calendar {calendar}",
    "You shared calendar {calendar} as public link" : "You shared calendar {calendar} as public link",
    "You removed public link for calendar {calendar}" : "You removed public link for calendar {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} shared calendar {calendar} with you",
    "You shared calendar {calendar} with {user}" : "You shared calendar {calendar} with {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} shared calendar {calendar} with {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} unshared calendar {calendar} from you",
    "You unshared calendar {calendar} from {user}" : "You unshared calendar {calendar} from {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} unshared calendar {calendar} from {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} unshared calendar {calendar} from themselves",
    "You shared calendar {calendar} with group {group}" : "You shared calendar {calendar} with group {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} shared calendar {calendar} with group {group}",
    "You unshared calendar {calendar} from group {group}" : "You unshared calendar {calendar} from group {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} unshared calendar {calendar} from group {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} created event {event} in calendar {calendar}",
    "You created event {event} in calendar {calendar}" : "You created event {event} in calendar {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} deleted event {event} from calendar {calendar}",
    "You deleted event {event} from calendar {calendar}" : "You deleted event {event} from calendar {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} updated event {event} in calendar {calendar}",
    "You updated event {event} in calendar {calendar}" : "You updated event {event} in calendar {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} created todo {todo} in list {calendar}",
    "You created todo {todo} in list {calendar}" : "You created todo {todo} in list {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} deleted todo {todo} from list {calendar}",
    "You deleted todo {todo} from list {calendar}" : "You deleted todo {todo} from list {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} updated todo {todo} in list {calendar}",
    "You updated todo {todo} in list {calendar}" : "You updated todo {todo} in list {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} solved todo {todo} in list {calendar}",
    "You solved todo {todo} in list {calendar}" : "You solved todo {todo} in list {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reopened todo {todo} in list {calendar}",
    "You reopened todo {todo} in list {calendar}" : "You reopened todo {todo} in list {calendar}",
    "A <strong>calendar</strong> was modified" : "A <strong>calendar</strong> was modified",
    "A calendar <strong>event</strong> was modified" : "A calendar <strong>event</strong> was modified",
    "A calendar <strong>todo</strong> was modified" : "A calendar <strong>todo</strong> was modified",
    "Contact birthdays" : "Contact birthdays",
    "%s via %s" : "%s via %s",
    "Invitation canceled" : "Invitation canceled",
    "Hello %s," : "Hello %s,",
    "The meeting »%s« with %s was canceled." : "The meeting »%s« with %s was canceled.",
    "Invitation updated" : "Invitation updated",
    "The meeting »%s« with %s was updated." : "The meeting »%s« with %s was updated.",
    "%s invited you to »%s«" : "%s invited you to »%s«",
    "When:" : "When:",
    "Where:" : "Where:",
    "Description:" : "Description:",
    "Link:" : "Link:",
    "Contacts" : "Contacts",
    "WebDAV" : "WebDAV",
    "Technical details" : "Technical details",
    "Remote Address: %s" : "Remote Address: %s",
    "Request ID: %s" : "Request ID: %s",
    "Send invitations to attendees" : "Send invitations to attendees",
    "Please make sure to properly set up the email settings above." : "Please make sure to properly set up the email settings above.",
    "Automatically generate a birthday calendar" : "Automatically generate a birthday calendar",
    "Birthday calendars will be generated by a background job." : "Birthday calendars will be generated by a background job.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Hence they will not be available immediately after enabling but will show up after some time.",
    "CalDAV server" : "CalDAV server"
},
"nplurals=2; plural=(n != 1);");
